@@ -30,6 +30,12 @@ impl Sem {
         }
     }
 
+    #[inline(always)]
+    ///Returns whether semaphore is successfully initialized
+    pub fn is_init(&self) -> bool {
+        !self.handle.load(Ordering::Acquire).is_null()
+    }
+
     #[must_use]
     ///Initializes semaphore with provided `init` as initial value.
     ///
@@ -38,21 +44,24 @@ impl Sem {
     ///Returns `false` if semaphore is already initialized or initialization failed.
     pub fn init(&self, init: u32) -> bool {
         if !self.handle.load(Ordering::Acquire).is_null() {
-            return unlikely(false);
-        }
+            //Similarly to `Once` we give priority to already-init path
+            return false;
+        } else {
+            let handle = unsafe {
+                CreateSemaphoreW(ptr::null_mut(), init as i32, i32::max_value(), ptr::null())
+            };
 
-        let handle = unsafe {
-            CreateSemaphoreW(ptr::null_mut(), init as i32, i32::max_value(), ptr::null())
-        };
-
-        match self.handle.compare_exchange(ptr::null_mut(), handle, Ordering::SeqCst, Ordering::Acquire) {
-            Ok(_) => !handle.is_null(),
-            Err(_) => {
-                unsafe {
-                    CloseHandle(handle);
+            let res = match self.handle.compare_exchange(ptr::null_mut(), handle, Ordering::SeqCst, Ordering::Acquire) {
+                Ok(_) => !handle.is_null(),
+                Err(_) => {
+                    unsafe {
+                        CloseHandle(handle);
+                    }
+                    unlikely(false)
                 }
-                unlikely(false)
-            }
+            };
+
+            unlikely(res)
         }
     }
 
